@@ -16,6 +16,8 @@ SERVER_EMAIL = FROM_EMAIL
 EMAIL_USE_TLS = True
 
 # Feedback settings
+FEEDBACK_FORM_TEXTCOLOR = '#fff'
+FEEDBACK_FORM_COLOR = '#660011'
 FEEDBACK_FORM_TEXT = """
 <h3>Hi! Do you have feedback or questions?</h3>
 <p>We'll answer as fast as possible.</p>
